# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ImagerService.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ImagerService.proto',
  package='endpoints.imager',
  syntax='proto3',
  serialized_options=b'\n\034com.kekflow.endpoints.imagerB\022ImagerServiceProtoP\001',
  serialized_pb=b'\n\x13ImagerService.proto\x12\x10\x65ndpoints.imager\"$\n\x14\x44ownloadImageRequest\x12\x0c\n\x04text\x18\x01 \x01(\t\"\'\n\tDataChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0c\n\x04size\x18\x02 \x01(\x05\x32\x64\n\rImagerService\x12S\n\x08getImage\x12&.endpoints.imager.DownloadImageRequest\x1a\x1b.endpoints.imager.DataChunk\"\x00\x30\x01\x42\x34\n\x1c\x63om.kekflow.endpoints.imagerB\x12ImagerServiceProtoP\x01\x62\x06proto3'
)




_DOWNLOADIMAGEREQUEST = _descriptor.Descriptor(
  name='DownloadImageRequest',
  full_name='endpoints.imager.DownloadImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='endpoints.imager.DownloadImageRequest.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=77,
)


_DATACHUNK = _descriptor.Descriptor(
  name='DataChunk',
  full_name='endpoints.imager.DataChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='endpoints.imager.DataChunk.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='endpoints.imager.DataChunk.size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=118,
)

DESCRIPTOR.message_types_by_name['DownloadImageRequest'] = _DOWNLOADIMAGEREQUEST
DESCRIPTOR.message_types_by_name['DataChunk'] = _DATACHUNK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DownloadImageRequest = _reflection.GeneratedProtocolMessageType('DownloadImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADIMAGEREQUEST,
  '__module__' : 'ImagerService_pb2'
  # @@protoc_insertion_point(class_scope:endpoints.imager.DownloadImageRequest)
  })
_sym_db.RegisterMessage(DownloadImageRequest)

DataChunk = _reflection.GeneratedProtocolMessageType('DataChunk', (_message.Message,), {
  'DESCRIPTOR' : _DATACHUNK,
  '__module__' : 'ImagerService_pb2'
  # @@protoc_insertion_point(class_scope:endpoints.imager.DataChunk)
  })
_sym_db.RegisterMessage(DataChunk)


DESCRIPTOR._options = None

_IMAGERSERVICE = _descriptor.ServiceDescriptor(
  name='ImagerService',
  full_name='endpoints.imager.ImagerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=120,
  serialized_end=220,
  methods=[
  _descriptor.MethodDescriptor(
    name='getImage',
    full_name='endpoints.imager.ImagerService.getImage',
    index=0,
    containing_service=None,
    input_type=_DOWNLOADIMAGEREQUEST,
    output_type=_DATACHUNK,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_IMAGERSERVICE)

DESCRIPTOR.services_by_name['ImagerService'] = _IMAGERSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import ImagerService_pb2 as ImagerService__pb2


class ImagerServiceStub(object):
    """Missing associated documentation comment in .proto file"""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.getImage = channel.unary_stream(
                '/endpoints.imager.ImagerService/getImage',
                request_serializer=ImagerService__pb2.DownloadImageRequest.SerializeToString,
                response_deserializer=ImagerService__pb2.DataChunk.FromString,
                )


class ImagerServiceServicer(object):
    """Missing associated documentation comment in .proto file"""

    def getImage(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ImagerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'getImage': grpc.unary_stream_rpc_method_handler(
                    servicer.getImage,
                    request_deserializer=ImagerService__pb2.DownloadImageRequest.FromString,
                    response_serializer=ImagerService__pb2.DataChunk.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'endpoints.imager.ImagerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ImagerService(object):
    """Missing associated documentation comment in .proto file"""

    @staticmethod
    def getImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/endpoints.imager.ImagerService/getImage',
            ImagerService__pb2.DownloadImageRequest.SerializeToString,
            ImagerService__pb2.DataChunk.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



import sys
import pathlib

from os import listdir
from os.path import isfile, join

curr_path = pathlib.Path(__file__).parent.absolute()
[sys.path.append(f) for f in listdir(curr_path) if isfile(join(curr_path, f))]



#!/usr/bin/env python

import os
from setuptools import setup, find_packages

DEFAULT_VERSION = '1.0-SNAPSHOT'

setup(name='kekflow_messages',
      version=os.getenv('VERSION', DEFAULT_VERSION),
      description='Kekflow  Utilities',
      packages=['kekflow_messages'],
      author='Kekflow',
      author_email='alex.agitolyev@gmail.com',
      python_requires='>=3.7',
     )
